@@ -4,9 +4,7 @@ use strict;
 use warnings;
 use parent qw(Exporter Digest::base);
 
-use MIME::Base64 ();
-
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 $VERSION = eval $VERSION;
 
 eval {
@@ -66,7 +64,8 @@ Digest::Shabal - Perl interface to the Shabal digest algorithm
 =head1 DESCRIPTION
 
 The C<Digest::Shabal> module provides an interface to the Shabal message
-digest algorithm. Shabal is a candidate in the NIST SHA-3 competition.
+digest algorithm. Shabal was a candidate in the NIST SHA-3 competition but
+did progress beyond round 2.
 
 This interface follows the conventions set forth by the C<Digest> module.
 
@@ -179,10 +178,10 @@ L<http://search.cpan.org/dist/Digest-Shabal/>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2010 gray <gray at cpan.org>, all rights reserved.
+Copyright (C) 2010-2017 gray <gray at cpan.org>, all rights reserved.
 
-This library is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
+This library is free software; you can redistribute it and/or modify it under
+the same terms as Perl itself.
 
 =head1 AUTHOR
 
